A deterministic adapter for contract and adapter-extension tests.
Pass a Jido.Chat.AdapterTestKit.MockTransport process as :transport in
operation options to record calls or supply queued provider responses.
A deterministic adapter for contract and adapter-extension tests.
Pass a Jido.Chat.AdapterTestKit.MockTransport process as :transport in
operation options to record calls or supply queued provider responses.