Canonical cross-platform card model with fallback rendering helpers.
Summary
Functions
Builds an actions component.
Adds a component to the end of a card.
Builds an area chart component.
Builds a bar chart component.
Builds a button component.
Builds a chart component from a chart type and data points.
Builds a named-series chart with ordered shared categories.
Builds a divider component.
Builds a dynamic select. This is an alias for external_select/2.
Builds a select whose options load from an external source.
Returns the best text fallback for a card.
Builds a field component.
Builds a grouped fields component.
Builds a card from serialized map data.
Builds an image component.
Builds a line chart component.
Builds a text link component.
Builds a link button component.
Builds a link button with an explicit action ID and options.
Creates a canonical card.
Normalizes card input.
Builds a pie chart component.
Builds a radio select component.
Returns the schema for cards.
Builds a section component.
Builds a select component.
Builds a select option component.
Builds a select option group.
Builds a table component.
Builds a text component.
Returns a plain map suitable for adapter-specific rendering.
Serializes a card into a plain map with a type marker.
Renders the card to canonical Markdown.
Types
Functions
Builds an actions component.
Adds a component to the end of a card.
Builds an area chart component.
Builds a bar chart component.
Builds a button component.
@spec chart( :pie | :bar | :area | :line | atom() | String.t(), list(), keyword() | map() ) :: component()
Builds a chart component from a chart type and data points.
Builds a named-series chart with ordered shared categories.
@spec divider() :: component()
Builds a divider component.
Builds a dynamic select. This is an alias for external_select/2.
Builds a select whose options load from an external source.
Returns the best text fallback for a card.
Builds a field component.
Builds a grouped fields component.
Builds a card from serialized map data.
Builds an image component.
Builds a line chart component.
Builds a text link component.
Builds a link button component.
Builds a link button with an explicit action ID and options.
Creates a canonical card.
Normalizes card input.
Builds a pie chart component.
Builds a radio select component.
Returns the schema for cards.
Builds a section component.
Builds a select component.
Builds a select option component.
Builds a select option group.
Builds a table component.
Builds a text component.
Returns a plain map suitable for adapter-specific rendering.
Serializes a card into a plain map with a type marker.
@spec to_markdown(t()) :: Jido.Chat.Markdown.t()
Renders the card to canonical Markdown.