Jido.Chat.Emoji (Jido Chat v1.0.0)

Copy Markdown View Source

Cross-platform emoji helper with a small default registry and custom overrides.

Summary

Functions

Adds or overrides a custom emoji entry in a registry.

Returns the built-in emoji registry.

Renders an emoji token using built-ins plus optional custom overrides.

Types

registry()

@type registry() :: %{optional(atom()) => String.t()}

Functions

put_custom(custom, name, rendered)

@spec put_custom(registry(), atom() | String.t(), String.t()) :: registry()

Adds or overrides a custom emoji entry in a registry.

registry()

@spec registry() :: registry()

Returns the built-in emoji registry.

render(value, opts \\ [])

@spec render(
  String.t() | atom(),
  keyword()
) :: String.t()

Renders an emoji token using built-ins plus optional custom overrides.