Jido.Chat.MessageContext (Jido Chat v1.2.0)

Copy Markdown View Source

Ordered message context for a collapsed queue or burst dispatch.

skipped contains the earlier messages from the same conversation. The current message is not in this list. total_since_last_handler and total_count have the same value. The second field gives callers a short, transport-neutral name while the first field matches the Chat SDK contract.

Summary

Functions

Creates normalized ordered message context.

Returns the schema for message context.

Types

t()

@type t() :: %Jido.Chat.MessageContext{
  skipped: [any()],
  total_count: integer(),
  total_since_last_handler: integer()
}

Functions

new(context)

@spec new(t() | map() | keyword()) :: t()

Creates normalized ordered message context.

schema()

@spec schema() :: Zoi.schema()

Returns the schema for message context.