Jido.Chat.MessageDeletedEvent (Jido Chat v1.2.0)

Copy Markdown View Source

A normalized event for deletion of an existing message.

message_id always identifies the deleted provider message. If the provider does not supply deleted content, message is nil. Core does not fetch or recover the missing content.

Summary

Functions

Builds the event from serialized map data.

Creates a normalized message-deleted event.

Returns the Zoi schema for MessageDeletedEvent.

Serializes the event into a plain map with a type marker.

Types

t()

@type t() :: %Jido.Chat.MessageDeletedEvent{
  adapter: nil | nil | any(),
  adapter_name: nil | nil | atom(),
  author:
    nil
    | nil
    | %Jido.Chat.Author{
        email: term(),
        full_name: term(),
        id: term(),
        is_bot: term(),
        is_me: term(),
        is_system: term(),
        metadata: term(),
        user_id: term(),
        user_name: term()
      },
  channel:
    nil
    | nil
    | %Jido.Chat.ChannelRef{
        adapter: term(),
        adapter_name: term(),
        external_id: term(),
        id: term(),
        metadata: term()
      },
  channel_id: nil | nil | binary(),
  message:
    nil
    | nil
    | %Jido.Chat.Message{
        attachments: term(),
        author: term(),
        channel_id: term(),
        created_at: term(),
        external_message_id: term(),
        external_reply_to_id: term(),
        external_room_id: term(),
        formatted: term(),
        id: term(),
        is_mention: term(),
        metadata: term(),
        raw: term(),
        reply_context: term(),
        text: term(),
        thread_id: term(),
        updated_at: term()
      },
  message_id: binary(),
  metadata: map(),
  raw: map(),
  thread:
    nil
    | nil
    | %Jido.Chat.Thread{
        adapter: term(),
        adapter_name: term(),
        channel_id: term(),
        external_room_id: term(),
        external_thread_id: term(),
        id: term(),
        is_dm: term(),
        metadata: term()
      },
  thread_id: nil | nil | binary(),
  timestamp: nil | nil | any()
}

Functions

from_map(map)

@spec from_map(map()) :: t()

Builds the event from serialized map data.

new(attrs)

@spec new(map()) :: t()

Creates a normalized message-deleted event.

schema()

Returns the Zoi schema for MessageDeletedEvent.

to_map(event)

@spec to_map(t()) :: map()

Serializes the event into a plain map with a type marker.