Jido.Chat.ThreadPage (Jido Chat v1.0.0)

Copy Markdown View Source

Canonical page of thread summaries.

Summary

Functions

Creates a canonical thread page and normalizes summary entries.

Returns the Zoi schema for ThreadPage.

Types

t()

@type t() :: %Jido.Chat.ThreadPage{
  metadata: map(),
  next_cursor: nil | nil | binary(),
  threads: [
    %Jido.Chat.ThreadSummary{
      id: term(),
      last_reply_at: term(),
      metadata: term(),
      reply_count: term(),
      root_message: term()
    }
  ]
}

Functions

new(attrs)

Creates a canonical thread page and normalizes summary entries.

schema()

Returns the Zoi schema for ThreadPage.