Jido.Chat.ThreadSummary (Jido Chat v1.0.0)

Copy Markdown View Source

Lightweight thread descriptor for channel-level thread listing.

Summary

Functions

Creates a thread summary and normalizes root message payload.

Returns the Zoi schema for ThreadSummary.

Types

t()

@type t() :: %Jido.Chat.ThreadSummary{
  id: binary(),
  last_reply_at: nil | nil | any(),
  metadata: map(),
  reply_count: nil | nil | integer(),
  root_message:
    nil
    | nil
    | %Jido.Chat.Message{
        attachments: term(),
        author: term(),
        channel_id: term(),
        created_at: term(),
        external_message_id: term(),
        external_room_id: term(),
        formatted: term(),
        id: term(),
        is_mention: term(),
        metadata: term(),
        raw: term(),
        text: term(),
        thread_id: term(),
        updated_at: term()
      }
}

Functions

new(attrs)

Creates a thread summary and normalizes root message payload.

schema()

Returns the Zoi schema for ThreadSummary.