Canonical cross-platform card model with fallback rendering helpers.
Summary
Functions
Builds an actions component.
Adds a component to the end of a card.
Builds a button component.
Builds a divider component.
Returns the best text fallback for a card.
Builds a field component.
Builds a grouped fields component.
Builds a card from serialized map data.
Builds an image component.
Builds a text link component.
Builds a link button component.
Creates a canonical card.
Normalizes card input.
Builds a radio select component.
Returns the schema for cards.
Builds a section component.
Builds a select component.
Builds a select option component.
Builds a table component.
Builds a text component.
Returns a plain map suitable for adapter-specific rendering.
Serializes a card into a plain map with a type marker.
Renders the card to canonical Markdown.
Types
Functions
Builds an actions component.
Adds a component to the end of a card.
Builds a button component.
@spec divider() :: component()
Builds a divider component.
Returns the best text fallback for a card.
Builds a field component.
Builds a grouped fields component.
Builds a card from serialized map data.
Builds an image component.
Builds a text link component.
Builds a link button component.
Creates a canonical card.
Normalizes card input.
Builds a radio select component.
Returns the schema for cards.
Builds a section component.
Builds a select component.
Builds a select option component.
Builds a table component.
Builds a text component.
Returns a plain map suitable for adapter-specific rendering.
Serializes a card into a plain map with a type marker.
@spec to_markdown(t()) :: Jido.Chat.Markdown.t()
Renders the card to canonical Markdown.