Canonical card component used by Jido.Chat.Card.
Summary
Functions
Builds a component from serialized data.
Creates a canonical card component.
Normalizes component input.
Returns the schema for a card component.
Serializes the component into a plain map with a type marker.
Types
@type t() :: %Jido.Chat.Card.Component{ alt_text: nil | nil | binary(), columns: [any()], disabled: boolean(), id: nil | nil | binary(), image_url: nil | nil | binary(), items: [any()], kind: :text | :section | :fields | :field | :button | :link_button | :link | :actions | :select | :select_option | :radio_select | :table | :image | :divider, label: nil | nil | binary(), markdown: nil | nil | any(), metadata: map(), options: [any()], rows: [any()], style: nil | nil | binary(), text: nil | nil | binary(), title: nil | nil | binary(), url: nil | nil | binary(), value: nil | nil | binary() }
Functions
Builds a component from serialized data.
Creates a canonical card component.
Normalizes component input.
Returns the schema for a card component.
Serializes the component into a plain map with a type marker.