Canonical normalized event envelope used by webhook and gateway ingestion.
Summary
Functions
Builds event envelope from serialized data.
Creates a canonical event envelope.
Returns the Zoi schema for EventEnvelope.
Serializes event envelope into a plain map with type marker.
Types
@type event_type() ::
:message
| :reaction
| :action
| :modal_submit
| :modal_close
| :slash_command
| :assistant_thread_started
| :assistant_context_changed
@type t() :: %Jido.Chat.EventEnvelope{ adapter_name: nil | nil | atom(), channel_id: nil | nil | binary(), event_type: :message | :reaction | :action | :modal_submit | :modal_close | :slash_command | :assistant_thread_started | :assistant_context_changed, id: binary(), message_id: nil | nil | binary(), metadata: map(), payload: nil | nil | any(), raw: map(), thread_id: nil | nil | binary() }
Functions
Builds event envelope from serialized data.
Creates a canonical event envelope.
Returns the Zoi schema for EventEnvelope.
Serializes event envelope into a plain map with type marker.