Transport-agnostic typed inbound routing result.
Supports both request-based inputs (for example webhook HTTP requests) and event-based inputs (for example polling or gateway listeners).
Summary
Functions
Builds ingress result from serialized data.
Creates a typed ingress result.
Returns the Zoi schema for IngressResult.
Serializes ingress result into a plain map with type marker.
Types
Functions
Builds ingress result from serialized data.
Creates a typed ingress result.
Returns the Zoi schema for IngressResult.
Serializes ingress result into a plain map with type marker.