Normalized media entry used in Jido.Chat.Incoming.
Summary
Functions
Creates a media struct from map input.
Normalizes supported attachment inputs into a canonical media struct.
Normalizes a list of attachments into canonical media structs.
Returns the Zoi schema for Media.
Types
@type input() :: t() | Jido.Chat.Content.Image.t() | Jido.Chat.Content.Audio.t() | Jido.Chat.Content.Video.t() | Jido.Chat.Content.File.t() | map() | String.t()
@type t() :: %Jido.Chat.Media{ duration: nil | nil | integer(), filename: nil | nil | binary(), height: nil | nil | integer(), kind: :image | :audio | :video | :file, media_type: nil | nil | binary(), metadata: map(), size_bytes: nil | nil | integer(), url: nil | nil | binary(), width: nil | nil | integer() }
Functions
Creates a media struct from map input.
Normalizes supported attachment inputs into a canonical media struct.
Normalizes a list of attachments into canonical media structs.
Returns the Zoi schema for Media.