Canonical modal lifecycle response used by submit and close handlers.
Summary
Functions
Builds a close response.
Builds a validation-error response.
Builds a modal response from serialized data.
Creates a canonical modal response.
Builds a push response with a new modal.
Returns the schema for modal responses.
Returns a plain adapter-facing response map.
Serializes the response into a plain map with a type marker.
Builds an update response with a replacement modal.
Types
Functions
Builds a close response.
Builds a validation-error response.
Builds a modal response from serialized data.
Creates a canonical modal response.
@spec push(Jido.Chat.Modal.t() | map(), keyword() | map()) :: t()
Builds a push response with a new modal.
Returns the schema for modal responses.
Returns a plain adapter-facing response map.
Serializes the response into a plain map with a type marker.
@spec update(Jido.Chat.Modal.t() | map(), keyword() | map()) :: t()
Builds an update response with a replacement modal.