Canonical sent-message handle with follow-up lifecycle operations.
Summary
Functions
Adds a reaction to the message when supported by the adapter.
Deletes the message when supported by the adapter.
Edits the message using the canonical outbound payload contract.
Builds a sent message from serialized map data.
Creates a sent-message handle from normalized adapter response data.
Removes a reaction from the message when supported by the adapter.
Returns the Zoi schema for SentMessage.
Serializes the sent message into a plain map with type marker.
Types
@type t() :: %Jido.Chat.SentMessage{ adapter: any(), attachments: [ %Jido.Chat.Attachment{ data: term(), duration: term(), filename: term(), height: term(), kind: term(), media_type: term(), metadata: term(), path: term(), size_bytes: term(), url: term(), width: term() } ], author: nil | nil | %Jido.Chat.Author{ full_name: term(), is_bot: term(), is_me: term(), metadata: term(), user_id: term(), user_name: term() }, default_opts: any(), external_room_id: nil | nil | any(), formatted: nil | nil | binary(), id: binary(), is_mention: boolean(), metadata: map(), raw: nil | nil | any(), response: %Jido.Chat.Response{ channel_id: term(), channel_type: term(), chat_id: term(), date: term(), external_message_id: term(), external_room_id: term(), message_id: term(), metadata: term(), raw: term(), status: term(), timestamp: term() }, text: nil | nil | binary(), thread_id: binary() }
Functions
Adds a reaction to the message when supported by the adapter.
Deletes the message when supported by the adapter.
@spec edit(t(), String.t() | Jido.Chat.Postable.t() | map(), keyword()) :: {:ok, t()} | {:error, term()}
Edits the message using the canonical outbound payload contract.
Builds a sent message from serialized map data.
Creates a sent-message handle from normalized adapter response data.
Removes a reaction from the message when supported by the adapter.
Returns the Zoi schema for SentMessage.
Serializes the sent message into a plain map with type marker.