Typed stream input chunk used by outbound stream payloads.
Summary
Functions
Returns the best text fallback for the chunk.
Builds a stream chunk from serialized map data.
Creates a stream chunk from normalized map input.
Normalizes supported stream chunk inputs.
Normalizes a list of stream chunk inputs.
Returns the Zoi schema for StreamChunk.
Builds a text chunk.
Serializes a stream chunk into a plain map with type marker.
Types
Functions
Returns the best text fallback for the chunk.
Builds a stream chunk from serialized map data.
Creates a stream chunk from normalized map input.
Normalizes supported stream chunk inputs.
Normalizes a list of stream chunk inputs.
Returns the Zoi schema for StreamChunk.
Builds a text chunk.
Serializes a stream chunk into a plain map with type marker.