Typed webhook request envelope used for adapter verification and parsing.
Summary
Functions
Builds webhook request from serialized data.
Gets a normalized request header value.
Creates a typed webhook request from raw map or HTTP-style request fields.
Returns the Zoi schema for WebhookRequest.
Serializes webhook request into plain map with type marker.
Types
Functions
Builds webhook request from serialized data.
Gets a normalized request header value.
Creates a typed webhook request from raw map or HTTP-style request fields.
Returns the Zoi schema for WebhookRequest.
Serializes webhook request into plain map with type marker.