Typed webhook response envelope.
Summary
Functions
Returns a default accepted response.
Returns an error response envelope.
Builds webhook response from serialized data.
Creates a typed webhook response envelope.
Returns the Zoi schema for WebhookResponse.
Serializes webhook response into plain map with type marker.
Types
Functions
Returns a default accepted response.
Returns an error response envelope.
Builds webhook response from serialized data.
Creates a typed webhook response envelope.
Returns the Zoi schema for WebhookResponse.
Serializes webhook response into plain map with type marker.